@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
-from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
+
+from urllib3.exceptions import ProtocolError
+
 from ocp_resources.logger import get_logger
-from ocp_resources.resource import NamespacedResource
+from ocp_resources.resource import TIMEOUT, NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 
 
@@ -31,7 +33,7 @@ class Deployment(NamespacedResource):
         LOGGER.info(f"Set deployment replicas: {replica_count}")
         return self.update(resource_dict=body)
 
-    def wait_for_replicas(self, deployed=True, timeout=TIMEOUT_4MINUTES):
+    def wait_for_replicas(self, deployed=True, timeout=TIMEOUT):
         """
         Wait until all replicas are updated.
 
@@ -46,26 +48,16 @@ class Deployment(NamespacedResource):
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=self.api.get,
+            exceptions=ProtocolError,
+            func=self.api().get,
             field_selector=f"metadata.name=={self.name}",
         )
         for sample in samples:
             if sample.items:
-                instance = sample.items[0]
-                status = instance.status
-
-                spec_replicas = instance.spec.replicas
-                total_replicas = status.replicas or 0
-                updated_replicas = status.updatedReplicas or 0
-                available_replicas = status.availableReplicas or 0
-                ready_replicas = status.readyReplicas or 0
-
-                if (
-                    (deployed and spec_replicas)
-                    and spec_replicas
-                    == updated_replicas
-                    == available_replicas
-                    == ready_replicas
-                ) or not (deployed or spec_replicas or total_replicas):
-                    return
+                status = sample.items[0].status
+                if deployed:
+                    if status.replicas == status.availableReplicas:
+                        return
+                else:
+                    if not status.availableReplicas:
+                        return
