@@ -2,7 +2,6 @@ import json
 
 import kubernetes
 
-from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.logger import get_logger
 from ocp_resources.node import Node
 from ocp_resources.resource import NamespacedResource
@@ -37,17 +36,11 @@ class Pod(NamespacedResource):
     api_version = NamespacedResource.ApiVersion.V1
 
     class Status(NamespacedResource.Status):
+        RUNNING = "Running"
         CRASH_LOOPBACK_OFF = "CrashLoopBackOff"
 
     def __init__(
-        self,
-        name=None,
-        namespace=None,
-        client=None,
-        teardown=True,
-        privileged_client=None,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
+        self, name, namespace, client=None, teardown=True, privileged_client=None
     ):
         super().__init__(
             name=name,
@@ -55,8 +48,6 @@ class Pod(NamespacedResource):
             client=client,
             teardown=teardown,
             privileged_client=privileged_client,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
         )
         self._kube_api = kubernetes.client.CoreV1Api(api_client=self.client.client)
 
@@ -70,7 +61,7 @@ class Pod(NamespacedResource):
         """
         return self.instance.spec.containers
 
-    def execute(self, command, timeout=60, container=None, ignore_rc=False):
+    def execute(self, command, timeout=60, container=None):
         """
         Run command on Pod
 
@@ -78,7 +69,6 @@ class Pod(NamespacedResource):
             command (list): Command to run.
             timeout (int): Time to wait for the command.
             container (str): Container name where to exec the command.
-            ignore_rc (bool): If True ignore error rc from the shell and return out.
 
         Returns:
             str: Command output.
@@ -127,9 +117,12 @@ class Pod(NamespacedResource):
         stdout = resp.read_stdout(timeout=5)
         stderr = resp.read_stderr(timeout=5)
 
-        if rcstring == "Success" or ignore_rc:
+        if rcstring == "Success":
             return stdout
 
+        if rcstring == "Failure":
+            raise ExecOnPodError(command=command, rc=-1, out="", err=error_channel)
+
         returncode = [
             int(cause["message"])
             for cause in error_channel["details"]["causes"]
