@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from ocp_resources.constants import TIMEOUT_4MINUTES
+
 from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 
@@ -16,41 +16,29 @@ class Route(NamespacedResource):
 
     def __init__(
         self,
-        name=None,
-        namespace=None,
+        name,
+        namespace,
         client=None,
         service=None,
         destination_ca_cert=None,
         teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        **kwargs,
     ):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
-            **kwargs,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.service = service
         self.destination_ca_cert = destination_ca_cert
 
     def to_dict(self):
-        res = super().to_dict()
-        if self.yaml_file:
-            return res
-
+        body = super().to_dict()
         if self.service:
-            res.update({"spec": {"to": {"kind": "Service", "name": self.service}}})
+            body.update({"spec": {"to": {"kind": "Service", "name": self.service}}})
         if self.destination_ca_cert:
-            res["spec"]["tls"] = {
+            body["spec"]["tls"] = {
                 "destinationCACertificate": self.destination_ca_cert,
                 "termination": "reencrypt",
             }
-        return res
+        return body
 
     @property
     def exposed_service(self):
