@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 
-from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
+
+from urllib3.exceptions import ProtocolError
+
 from ocp_resources.logger import get_logger
-from ocp_resources.resource import NamespacedResource
+from ocp_resources.resource import TIMEOUT, NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 from ocp_resources.virtual_machine import VirtualMachine
 
@@ -17,31 +19,14 @@ class VirtualMachineSnapshot(NamespacedResource):
 
     api_group = NamespacedResource.ApiGroup.SNAPSHOT_KUBEVIRT_IO
 
-    def __init__(
-        self,
-        name=None,
-        namespace=None,
-        vm_name=None,
-        client=None,
-        teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-    ):
+    def __init__(self, name, namespace, vm_name, client=None, teardown=True):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.vm_name = vm_name
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         spec = res.setdefault("spec", {})
         spec.setdefault("source", {})[
             "apiGroup"
@@ -50,7 +35,7 @@ class VirtualMachineSnapshot(NamespacedResource):
         spec["source"]["name"] = self.vm_name
         return res
 
-    def wait_ready_to_use(self, status=True, timeout=TIMEOUT_4MINUTES):
+    def wait_ready_to_use(self, status=True, timeout=TIMEOUT):
         """
         Wait for VirtualMachineSnapshot to be in readyToUse status
 
@@ -68,7 +53,7 @@ class VirtualMachineSnapshot(NamespacedResource):
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
+            exceptions=ProtocolError,
             func=lambda: self.instance.get("status", {}).get("readyToUse", None)
             == status,
         )
